==> chromium-55.0.2883.75.tar.xz: chromium-55.0.2883.75/chrome/browser/ui/app_list/arc/arc_package_sync_data_type_controller.h <==
// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_UI_APP_LIST_ARC_ARC_PACKAGE_SYNC_DATA_TYPE_CONTROLLER_H_
#define CHROME_BROWSER_UI_APP_LIST_ARC_ARC_PACKAGE_SYNC_DATA_TYPE_CONTROLLER_H_

#include "base/macros.h"
#include "chrome/browser/ui/app_list/arc/arc_app_list_prefs.h"
#include "components/prefs/pref_change_registrar.h"
#include "components/sync/driver/data_type_controller.h"
#include "components/sync/driver/ui_data_type_controller.h"

class Profile;

namespace syncer {
class SyncClient;
}

// A UIDataTypeController for arc package sync datatypes, which enables or
// disables these types based on whether ArcAppInstance is ready.
class ArcPackageSyncDataTypeController : public syncer::UIDataTypeController,
                                         public ArcAppListPrefs::Observer {
 public:
  // |dump_stack| is called when an unrecoverable error occurs.
  ArcPackageSyncDataTypeController(syncer::ModelType type,
                                   const base::Closure& dump_stack,
                                   syncer::SyncClient* sync_client,
                                   Profile* profile);
  ~ArcPackageSyncDataTypeController() override;

  // UIDataTypeController override:
  bool ReadyForStart() const override;
  bool StartModels() override;
  void StopModels() override;

 private:
  // ArcAppListPrefs::Observer:
  void OnPackageListInitialRefreshed() override;

  void OnArcEnabledPrefChanged();

  void EnableDataType();

  bool ShouldSyncArc() const;

  bool model_normal_start_ = true;

  Profile* const profile_;

  syncer::SyncClient* sync_client_;

  PrefChangeRegistrar pref_registrar_;

  DISALLOW_COPY_AND_ASSIGN(ArcPackageSyncDataTypeController);
};
#endif  // CHROME_BROWSER_UI_APP_LIST_ARC_ARC_PACKAGE_SYNC_DATA_TYPE_CONTROLLER_H_

==> chromium-57.0.2987.11.tar.xz: chromium-57.0.2987.11/chrome/browser/ui/app_list/arc/arc_package_sync_data_type_controller.h <==
// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_UI_APP_LIST_ARC_ARC_PACKAGE_SYNC_DATA_TYPE_CONTROLLER_H_
#define CHROME_BROWSER_UI_APP_LIST_ARC_ARC_PACKAGE_SYNC_DATA_TYPE_CONTROLLER_H_

#include "base/macros.h"
#include "chrome/browser/ui/app_list/arc/arc_app_list_prefs.h"
#include "components/prefs/pref_change_registrar.h"
#include "components/sync/driver/async_directory_type_controller.h"
#include "components/sync/driver/data_type_controller.h"

class Profile;

namespace syncer {
class SyncClient;
}

// A DataTypeController for arc package sync datatypes, which enables or
// disables these types based on whether ArcAppInstance is ready.
class ArcPackageSyncDataTypeController
    : public syncer::AsyncDirectoryTypeController,
      public ArcAppListPrefs::Observer {
 public:
  // |dump_stack| is called when an unrecoverable error occurs.
  ArcPackageSyncDataTypeController(syncer::ModelType type,
                                   const base::Closure& dump_stack,
                                   syncer::SyncClient* sync_client,
                                   Profile* profile);
  ~ArcPackageSyncDataTypeController() override;

  // AsyncDirectoryTypeController implementation.
  bool ReadyForStart() const override;
  bool StartModels() override;
  void StopModels() override;

 private:
  // ArcAppListPrefs::Observer:
  void OnPackageListInitialRefreshed() override;

  void OnArcEnabledPrefChanged();

  void EnableDataType();

  bool ShouldSyncArc() const;

  bool model_normal_start_ = true;

  Profile* const profile_;

  PrefChangeRegistrar pref_registrar_;

  DISALLOW_COPY_AND_ASSIGN(ArcPackageSyncDataTypeController);
};
#endif  // CHROME_BROWSER_UI_APP_LIST_ARC_ARC_PACKAGE_SYNC_DATA_TYPE_CONTROLLER_H_
